==> octave2.1_2.1.69.orig.tar.gz: octave-2.1.69/src/pt-exp.cc <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
#pragma implementation
#endif

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <iostream>
#include <string>

#include "error.h"
#include "pager.h"
#include "oct-lvalue.h"
#include "ov.h"
#include "pt-exp.h"

// Expressions.

bool
tree_expression::is_logically_true (const char *warn_for)
{
  bool expr_value = false;

  octave_value t1 = rvalue ();

  if (! error_state)
    {
      if (t1.is_defined ())
	return t1.is_true ();
      else
	::error ("%s: undefined value used in conditional expression",
		 warn_for);
    }
  else
    ::error ("%s: error evaluating conditional expression", warn_for);

  return expr_value;
}

octave_value
tree_expression::rvalue (void)
{
  ::error ("invalid rvalue function called in expression");
  return octave_value ();
}

octave_value_list
tree_expression::rvalue (int)
{
  ::error ("invalid rvalue function called in expression");
  return octave_value_list ();
}

octave_lvalue
tree_expression::lvalue (void)
{
  ::error ("invalid lvalue function called in expression");
  return octave_lvalue ();
}

std::string
tree_expression::original_text (void) const
{
  return std::string ();
}

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave2.1_2.1.73.orig.tar.gz: octave-2.1.73/src/pt-exp.cc <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.

*/

#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
#pragma implementation
#endif

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <iostream>
#include <string>

#include "error.h"
#include "pager.h"
#include "oct-lvalue.h"
#include "ov.h"
#include "pt-exp.h"

// Expressions.

bool
tree_expression::is_logically_true (const char *warn_for)
{
  bool expr_value = false;

  octave_value t1 = rvalue ();

  if (! error_state)
    {
      if (t1.is_defined ())
	return t1.is_true ();
      else
	::error ("%s: undefined value used in conditional expression",
		 warn_for);
    }
  else
    ::error ("%s: error evaluating conditional expression", warn_for);

  return expr_value;
}

octave_value
tree_expression::rvalue (void)
{
  ::error ("invalid rvalue function called in expression");
  return octave_value ();
}

octave_value_list
tree_expression::rvalue (int)
{
  ::error ("invalid rvalue function called in expression");
  return octave_value_list ();
}

octave_lvalue
tree_expression::lvalue (void)
{
  ::error ("invalid lvalue function called in expression");
  return octave_lvalue ();
}

std::string
tree_expression::original_text (void) const
{
  return std::string ();
}

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
